==> qtdeclarative-everywhere-opensource-src-6.2.9.zip: qtdeclarative-everywhere-src-6.2.9/src/quickwidgets/qaccessiblequickwidget_p.h <==
/****************************************************************************
**
** Copyright (C) 2021 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of the QtQuick module of the Qt Toolkit.
**
** $QT_BEGIN_LICENSE:LGPL$
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 3 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL3 included in the
** packaging of this file. Please review the following information to
** ensure the GNU Lesser General Public License version 3 requirements
** will be met: https://www.gnu.org/licenses/lgpl-3.0.html.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 2.0 or (at your option) the GNU General
** Public license version 3 or any later version approved by the KDE Free
** Qt Foundation. The licenses are as published by the Free Software
** Foundation and appearing in the file LICENSE.GPL2 and LICENSE.GPL3
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-2.0.html and
** https://www.gnu.org/licenses/gpl-3.0.html.
**
** $QT_END_LICENSE$
**
****************************************************************************/

#ifndef QACCESSIBLEQUICKWIDGET_H
#define QACCESSIBLEQUICKWIDGET_H

//
//  W A R N I N G
//  -------------
//
// This file is not part of the Qt API.  It exists purely as an
// implementation detail.  This header file may change from version to
// version without notice, or even be removed.
//
// We mean it.
//

#include "qquickwidget.h"
#include <QtWidgets/qaccessiblewidget.h>

#include <private/qaccessiblequickview_p.h>

QT_BEGIN_NAMESPACE

#if QT_CONFIG(accessibility)

// These classes implement the QQuickWiget accessibility switcharoo,
// where the child items of the QQuickWidgetOffscreenWindow are reported
// as child accessible interfaces of the QAccessibleQuickWidget.
class QAccessibleQuickWidget: public QAccessibleWidget
{
public:
    QAccessibleQuickWidget(QQuickWidget* widget);

    QAccessibleInterface *child(int index) const override;
    int childCount() const override;
    int indexOfChild(const QAccessibleInterface *iface) const override;
    QAccessibleInterface *childAt(int x, int y) const override;

private:
    QAccessibleQuickWindow m_accessibleWindow;
    Q_DISABLE_COPY(QAccessibleQuickWidget)
};

class QAccessibleQuickWidgetOffscreenWindow: public QAccessibleQuickWindow
{
public:
    QAccessibleQuickWidgetOffscreenWindow(QQuickWindow *window);
    QAccessibleInterface *child(int index) const override;
    int childCount() const override;
    int indexOfChild(const QAccessibleInterface *iface) const override;
    QAccessibleInterface *childAt(int x, int y) const override;
};

#endif // accessibility

QT_END_NAMESPACE

#endif

==> qtdeclarative-everywhere-opensource-src-6.5.5.zip: qtdeclarative-everywhere-src-6.5.5/src/quickwidgets/qaccessiblequickwidget_p.h <==
// Copyright (C) 2021 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

#ifndef QACCESSIBLEQUICKWIDGET_H
#define QACCESSIBLEQUICKWIDGET_H

//
//  W A R N I N G
//  -------------
//
// This file is not part of the Qt API.  It exists purely as an
// implementation detail.  This header file may change from version to
// version without notice, or even be removed.
//
// We mean it.
//

#include "qquickwidget.h"
#include <QtWidgets/qaccessiblewidget.h>

#include <private/qaccessiblequickview_p.h>

QT_BEGIN_NAMESPACE

#if QT_CONFIG(accessibility)

// These classes implement the QQuickWiget accessibility switcharoo,
// where the child items of the QQuickWidgetOffscreenWindow are reported
// as child accessible interfaces of the QAccessibleQuickWidget.
class QAccessibleQuickWidget: public QAccessibleWidget
{
public:
    QAccessibleQuickWidget(QQuickWidget* widget);
    ~QAccessibleQuickWidget();

    QAccessibleInterface *child(int index) const override;
    int childCount() const override;
    int indexOfChild(const QAccessibleInterface *iface) const override;
    QAccessibleInterface *childAt(int x, int y) const override;

private:
    void repairWindow();

    std::unique_ptr<QAccessibleQuickWindow> m_accessibleWindow;
    QMetaObject::Connection m_connection;
    Q_DISABLE_COPY(QAccessibleQuickWidget)
};

class QAccessibleQuickWidgetOffscreenWindow: public QAccessibleQuickWindow
{
public:
    QAccessibleQuickWidgetOffscreenWindow(QQuickWindow *window);
    QAccessibleInterface *child(int index) const override;
    int childCount() const override;
    int indexOfChild(const QAccessibleInterface *iface) const override;
    QAccessibleInterface *childAt(int x, int y) const override;
};

#endif // accessibility

QT_END_NAMESPACE

#endif
